@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2008-2012 Luc Saffre
+## Copyright 2008-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -12,6 +12,11 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
+"""
+Adds PCSW-specific demo data.
+"""
+
+from __future__ import unicode_literals
 
 import decimal
 #~ from dateutil.relativedelta import relativedelta
@@ -26,6 +31,7 @@ from django.utils.translation import ugettext as _
 
 
 from lino import dd
+from lino import mixins
 from lino.utils import i2d, Cycler
 from lino.utils.instantiator import Instantiator
 from lino.core.modeltools import resolve_model
@@ -34,12 +40,11 @@ from lino.utils.restify import restify
 from lino.utils import dblogger
 #~ from lino.models import update_site_config
 from lino.utils import mti
-from lino.utils.niss import gen_niss
+from lino.utils.ssin import generate_ssin
 
 #~ from django.contrib.auth import models as auth
 #~ from lino.modlib.users import models as auth
-from lino.modlib.contacts.utils import Gender
-#~ from lino.utils.choicelists import Gender
+#~ from lino.modlib.contacts.utils import Gender
 from lino_welfare.modlib.jobs import models as jobs
 from lino.modlib.contacts import models as contacts
 from lino.modlib.countries import models as countries
@@ -275,8 +280,8 @@ def objects():
   
     ClientContactType = resolve_model('pcsw.ClientContactType')
   
-    Person = resolve_model(settings.LINO.person_model)
-    Company = resolve_model(settings.LINO.company_model)
+    Person = resolve_model('contacts.Person')
+    Company = resolve_model('contacts.Company')
     #~ Contact = resolve_model('contacts.Contact')
     Role = resolve_model('contacts.Role')
     RoleType = resolve_model('contacts.RoleType')
@@ -286,6 +291,7 @@ def objects():
     #~ Function = resolve_model('jobs.Function')
     #~ Sector = resolve_model('jobs.Sector')
     User = resolve_model('users.User')
+    Authority = resolve_model('users.Authority')
     #~ Country = resolve_model('countries.Country')
     Client = resolve_model('pcsw.Client')
     
@@ -345,7 +351,7 @@ def objects():
     yield company(name=u"Behindertenstätten Eupen",city=eupen,country=belgium)
     yield company(name=u"Beschützende Werkstätte Eupen",city=eupen,country=belgium)
     
-    cct = ClientContactType(name="Krankenkasse")
+    cct = ClientContactType(name=u"Krankenkasse")
     yield cct
     kw = dict(client_contact_type=cct,country=belgium)
     #~ kw = dict(is_health_insurance=True,country=belgium)
@@ -355,7 +361,7 @@ def objects():
     yield company(name=u"Mutualia - Mutualité Neutre",**kw)
     yield company(name=u"Solidaris - Mutualité socialiste et syndicale de la province de Liège",**kw)
     
-    cct = ClientContactType(name="Apotheke")
+    cct = ClientContactType(name=u"Apotheke")
     yield cct
     kw = dict(client_contact_type=cct,country=belgium)
     #~ kw = dict(is_pharmacy=True,country=belgium,city=eupen)
@@ -389,32 +395,21 @@ def objects():
     
     ly = person(first_name="Ly",last_name="Rumma",
       city=vigala,country='EE',
-      #~ card_number='123',birth_country=ee,birth_date='0000-04-27',
-      #~ national_id='1234',
-      #~ client_state=pcsw.ClientStates.newcomer,
-      gender=Gender.female)
+      gender=mixins.Genders.female)
     yield ly
     mari = person(first_name="Mari",last_name="Saffre",
       city=vigala,country='EE',
-      #~ card_number='124',birth_country=ee,
-      #~ birth_date=i2d(20020405),
-      #~ national_id='1235',
-      #~ client_state=pcsw.ClientStates.newcomer,
-      gender=Gender.female)
+      gender=mixins.Genders.female)
     yield mari
     iiris = person(first_name="Iiris",last_name="Saffre",
       city=vigala,country='EE',
-      #~ card_number='125',birth_country=ee,
-      #~ birth_date=i2d(20080324),
-      #~ national_id='1236',
-      #~ client_state=pcsw.ClientStates.newcomer,
-      gender=Gender.female)
+      gender=mixins.Genders.female)
     yield iiris
     
     gerd = person(first_name="Gerd",
       last_name="Xhonneux",city=kettenis,
       email='gerd@example.com',
-      name="Xhonneux Gerd",country='BE',gender=Gender.male)
+      country='BE',gender=mixins.Genders.male)
     yield gerd
     yield role(company=cpas,person=gerd,type=4)
     #~ yield link(a=cpas,b=gerd,type=4)
@@ -424,11 +419,11 @@ def objects():
         first_name=u"Tatjana",last_name=u"Kasennova",
         #~ first_name=u"Татьяна",last_name=u"Казеннова",
         city=kettenis,country='BE', 
-        national_id='1237',
+        #~ national_id='1237',
         birth_place="Moskau", # birth_country='SUHH',
         client_state=pcsw.ClientStates.newcomer,
         #~ newcomer=True,
-        gender=Gender.female)
+        gender=mixins.Genders.female)
     yield tatjana
     
     bernard = Person.objects.get(name__exact="Bodard Bernard")
@@ -437,8 +432,11 @@ def objects():
     yield cct
     kw = dict(client_contact_type=cct,country=belgium,city=eupen)
     adg = company(name=u"Arbeitsamt der D.G.",**kw)
+    adg.save()
     yield adg
-    settings.LINO.update_site_config(job_office=adg)
+    #~ settings.LINO.update_site_config(job_office=adg)
+    settings.LINO.site_config.job_office = adg
+    yield settings.LINO.site_config
     adg_dir = role(company=adg,person=bernard,type=1)
     #~ adg_dir = link(a=adg,b=bernard,type=1)
     yield adg_dir
@@ -456,53 +454,45 @@ def objects():
       
     DIRECTORS = (annette,hans,andreas,bernard)
     
-    yield User(username='gerd',partner=gerd,profile='900')
+    #~ yield User(username='gerd',partner=gerd,profile='900')
     
-    melanie = person(first_name=u"Mélanie",last_name=u"Mélard",
+    melanie = person(first_name="Mélanie",last_name="Mélard",
         email='melanie@example.com',
-        city=eupen,country='BE',gender=Gender.female,language='fr')
+        city=eupen,country='BE',gender=mixins.Genders.female,
+        language='fr')
     yield melanie
     melanie = User(username="melanie",partner=melanie,profile='110') 
     yield melanie
     
     hubert = person(first_name=u"Hubert",last_name=u"Huppertz",
         email='hubert@example.com',
-        city=eupen,country='BE',gender=Gender.male)
+        city=eupen,country='BE',gender=mixins.Genders.male)
     yield hubert
     hubert = User(username="hubert",partner=hubert,profile='100') 
     yield hubert
     
     alicia = person(first_name=u"Alicia",last_name=u"Allmanns",
         email='alicia@example.com',
-        city=eupen,country='BE',gender=Gender.female)
+        city=eupen,country='BE',gender=mixins.Genders.female,language='fr')
     yield alicia
     alicia = User(username="alicia",partner=alicia,profile='100') 
     yield alicia
     
-    elmar = person(first_name=u"Elmar",last_name=u"Elsen",
-        city=eupen,country='BE',gender=Gender.male)
-    yield elmar
-    elmar = User(username="elmar",partner=elmar,profile='400') 
-    yield elmar
+    yield Authority(user=alicia,authorized=hubert)
+    yield Authority(user=alicia,authorized=melanie)
+    yield Authority(user=hubert,authorized=melanie)
     
-    charles = person(first_name=u"Charles",last_name=u"Cabeil-Esaice",
-        city=eupen,country='BE',gender=Gender.male)
-    yield charles
-    charles = User(username="charles",partner=charles,profile='500') 
-    yield charles
-    
-    
-    yield User(username="caroline",
+    caroline = User(username="caroline",
         first_name="Caroline",last_name="Carnol",
         profile='200') # UserProfiles.caroline)
-    
+    yield caroline
     
     # id must be 1 (see isip.ContactBase.person_changed
     yield pcsw.CoachingType(name="ASD",id=1) 
     
-    obj = User.objects.get(username="caroline")
-    obj.coaching_type_id = 1
-    obj.save()
+    #~ caroline = User.objects.get(username="caroline")
+    caroline.coaching_type_id = 1
+    caroline.save()
     
     DSBE = pcsw.CoachingType(name="DSBE")
     yield DSBE
@@ -527,7 +517,7 @@ def objects():
           if contacts.Role.objects.filter(person=person).count() == 0:
             #~ if not person in DIRECTORS:
             birth_date = settings.LINO.demo_date(-170*count - 16*365)  # '810601 211-83'
-            national_id = gen_niss(birth_date,person.gender)
+            national_id = generate_ssin(birth_date,person.gender)
                 
             client = person2client(person,
                 national_id=national_id,
@@ -578,7 +568,7 @@ def objects():
     
     Note = resolve_model('notes.Note')
     USERS = Cycler(User.objects.all())
-    SUBJECTS = Cycler("""
+    SUBJECTS = Cycler(u"""
     Erstgespräch
     Versammlung beim AG
     Zwischenbericht
@@ -829,97 +819,6 @@ def objects():
       c.short_code = short_code
       c.save()
       
-    root = User.objects.get(username='root')
-      
-    #~ p = Client.objects.get(name=u"Ärgerlich Erna")
-    #~ p.birth_date = i2d(19800301)
-    #~ p.coached_from = settings.LINO.demo_date(-7*30)
-    #~ p.coached_until = None
-    #~ p.coach1 = root
-    #~ p.coach2 = alicia # User.objects.get(username='alicia')
-    #~ p.gender = Gender.female 
-    #~ p.group = pg1
-    #~ p.save()
-    
-    #~ yield coachings(p,COACHINGTYPES.pop(),root,alicia,settings.LINO.demo_date(-7*30))
-    
-    #~ task = Instantiator('cal.Task').build
-    #~ yield task(user=root,start_date=i2d(20110717),
-        #~ summary=u"Anrufen Termin",
-        #~ owner=p)
-    
-    #~ p = Client.objects.get(name=u"Eierschal Emil")
-    #~ p.birth_date = i2d(19800501)
-    #~ p.coached_from = settings.LINO.demo_date(-2*30)
-    #~ p.coached_until = settings.LINO.demo_date(10*30)
-    #~ p.coach1 = User.objects.get(username='root')
-    #~ p.group = pg2
-    #~ p.gender = Gender.male
-    #~ p.national_id = 'INVALID-45'
-    #~ p.save()
-    
-    #~ yield coachings(p,COACHINGTYPES.pop(),root,None,settings.LINO.demo_date(-2*30),settings.LINO.demo_date(10*30))
-
-    #~ p = Client.objects.get(name=u"Bastiaensen Laurent")
-    #~ p.birth_date = i2d(19810601)
-    #~ p.coached_from = None
-    #~ p.coached_until = settings.LINO.demo_date(-2*30)
-    #~ p.unavailable_until = settings.LINO.demo_date(2*30)
-    #~ p.coach1 = User.objects.get(username='root')
-    #~ p.coach2 = alicia # User.objects.get(username='alicia')
-    #~ p.group = pg1
-    #~ p.gender = Gender.male
-    #~ p.national_id = '810601 211-83'
-    #~ p.save()
-
-    #~ yield coachings(p,COACHINGTYPES.pop(),root,alicia,None,settings.LINO.demo_date(-2*30))
-    
-    #~ p = Client.objects.get(name=u"Chantraine Marc")
-    #~ p.birth_date = i2d(19500301)
-    #~ p.coached_from = settings.LINO.demo_date(10)
-    #~ p.coached_until = None
-    #~ p.coach1 = User.objects.get(username='root')
-    #~ p.group = pg2
-    #~ p.gender = Gender.male
-    #~ p.save()
-
-    #~ yield coachings(p,COACHINGTYPES.pop(),root,None,settings.LINO.demo_date(10),None)
-    
-    #~ p = Client.objects.get(name=u"Charlier Ulrike")
-    #~ p.birth_date = i2d(19600401)
-    #~ p.coached_from = settings.LINO.demo_date(-3*30)
-    #~ p.coached_until = None
-    #~ p.coach1 = alicia # User.objects.get(username='alicia')
-    #~ p.gender = Gender.female
-    #~ p.group = pg1
-    #~ p.save()
-    
-    #~ yield coachings(p,COACHINGTYPES.pop(),alicia,None,settings.LINO.demo_date(-3*30),None)
-
-
-    #~ p = Client.objects.get(name=u"Collard Charlotte")
-    #~ p.birth_date = i2d(19800401)
-    #~ p.coached_from = settings.LINO.demo_date(-6*30)
-    #~ p.coached_until = None
-    #~ p.coach1 = User.objects.get(username='root')
-    #~ p.gender = Gender.female
-    #~ p.group = standby
-    #~ p.save()
-    
-    #~ yield coachings(p,COACHINGTYPES.pop(),root,None,settings.LINO.demo_date(-6*30),None)
-
-    #~ etype = Instantiator('cal.EventType','name').build
-    #~ yield etype("interner Termin")
-    #~ yield etype("Termin beim Klienten")
-    #~ yield etype("Termin beim Arbeitgeber")
-    
-    #~ event = Instantiator('cal.Event',
-      #~ 'start_date project summary',
-      #~ user=alicia).build
-    #~ yield event(settings.LINO.demo_date(+1),hans,u"Stand der Dinge")
-    #~ yield event(settings.LINO.demo_date(+1),annette,u"Problem Kühlschrank")
-    #~ yield event(settings.LINO.demo_date(+2),andreas,u"Mein dritter Termin")
-
     i = pcsw.Client.objects.order_by('name').__iter__()
     p = i.next()
     offset = 0
@@ -931,7 +830,7 @@ def objects():
         offset -= 1
         
     PERSONGROUPS = Cycler(pcsw.PersonGroup.objects.all())
-    AGENTS_SCATTERED = Cycler(alicia,hubert,melanie,melanie, hubert, melanie)
+    AGENTS_SCATTERED = Cycler(alicia,hubert,melanie,caroline, hubert,melanie, hubert, melanie)
     #~ for client in pcsw.Client.objects.exclude(client_state=pcsw.ClientStates.newcomer):
     for client in pcsw.Client.objects.all():
     #~ for i in range(30):
@@ -945,7 +844,10 @@ def objects():
                 client.save()
             periods = story.pop()
             for a,b,primary in periods:
-                kw = dict(client=client,type=COACHINGTYPES.pop(),user=AGENTS_SCATTERED.pop(),primary=primary)
+                kw = dict(client=client,
+                    type=COACHINGTYPES.pop(),
+                    user=AGENTS_SCATTERED.pop(),
+                    primary=primary)
                 if a is not None:
                     kw.update(start_date=settings.LINO.demo_date(a))
                 if b is not None:
